==> cinnamon-settings-daemon-5.2.0-x86_64-1_csb.txz: install/doinst.sh <==
if [ -e usr/share/icons/hicolor/icon-theme.cache ]; then
  if [ -x /usr/bin/gtk-update-icon-cache ]; then
    /usr/bin/gtk-update-icon-cache usr/share/icons/hicolor >/dev/null 2>&1
  fi
fi

if [ -e usr/share/glib-2.0/schemas ]; then
  if [ -x /usr/bin/glib-compile-schemas ]; then
    /usr/bin/glib-compile-schemas usr/share/glib-2.0/schemas >/dev/null 2>&1
  fi
fi
( cd usr/bin ; rm -rf csd-a11y-keyboard )
( cd usr/bin ; ln -sf ../libexec/csd-a11y-keyboard csd-a11y-keyboard )
( cd usr/bin ; rm -rf csd-a11y-settings )
( cd usr/bin ; ln -sf ../libexec/csd-a11y-settings csd-a11y-settings )
( cd usr/bin ; rm -rf csd-automount )
( cd usr/bin ; ln -sf ../libexec/csd-automount csd-automount )
( cd usr/bin ; rm -rf csd-background )
( cd usr/bin ; ln -sf ../libexec/csd-background csd-background )
( cd usr/bin ; rm -rf csd-backlight-helper )
( cd usr/bin ; ln -sf ../libexec/csd-backlight-helper csd-backlight-helper )
( cd usr/bin ; rm -rf csd-clipboard )
( cd usr/bin ; ln -sf ../libexec/csd-clipboard csd-clipboard )
( cd usr/bin ; rm -rf csd-color )
( cd usr/bin ; ln -sf ../libexec/csd-color csd-color )
( cd usr/bin ; rm -rf csd-cursor )
( cd usr/bin ; ln -sf ../libexec/csd-cursor csd-cursor )
( cd usr/bin ; rm -rf csd-housekeeping )
( cd usr/bin ; ln -sf ../libexec/csd-housekeeping csd-housekeeping )
( cd usr/bin ; rm -rf csd-input-helper )
( cd usr/bin ; ln -sf ../libexec/csd-input-helper csd-input-helper )
( cd usr/bin ; rm -rf csd-keyboard )
( cd usr/bin ; ln -sf ../libexec/csd-keyboard csd-keyboard )
( cd usr/bin ; rm -rf csd-list-wacom )
( cd usr/bin ; ln -sf ../libexec/csd-list-wacom csd-list-wacom )
( cd usr/bin ; rm -rf csd-locate-pointer )
( cd usr/bin ; ln -sf ../libexec/csd-locate-pointer csd-locate-pointer )
( cd usr/bin ; rm -rf csd-media-keys )
( cd usr/bin ; ln -sf ../libexec/csd-media-keys csd-media-keys )
( cd usr/bin ; rm -rf csd-mouse )
( cd usr/bin ; ln -sf ../libexec/csd-mouse csd-mouse )
( cd usr/bin ; rm -rf csd-orientation )
( cd usr/bin ; ln -sf ../libexec/csd-orientation csd-orientation )
( cd usr/bin ; rm -rf csd-power )
( cd usr/bin ; ln -sf ../libexec/csd-power csd-power )
( cd usr/bin ; rm -rf csd-print-notifications )
( cd usr/bin ; ln -sf ../libexec/csd-print-notifications csd-print-notifications )
( cd usr/bin ; rm -rf csd-printer )
( cd usr/bin ; ln -sf ../libexec/csd-printer csd-printer )
( cd usr/bin ; rm -rf csd-screensaver-proxy )
( cd usr/bin ; ln -sf ../libexec/csd-screensaver-proxy csd-screensaver-proxy )
( cd usr/bin ; rm -rf csd-smartcard )
( cd usr/bin ; ln -sf ../libexec/csd-smartcard csd-smartcard )
( cd usr/bin ; rm -rf csd-sound )
( cd usr/bin ; ln -sf ../libexec/csd-sound csd-sound )
( cd usr/bin ; rm -rf csd-wacom )
( cd usr/bin ; ln -sf ../libexec/csd-wacom csd-wacom )
( cd usr/bin ; rm -rf csd-wacom-osd )
( cd usr/bin ; ln -sf ../libexec/csd-wacom-osd csd-wacom-osd )
( cd usr/bin ; rm -rf csd-xrandr )
( cd usr/bin ; ln -sf ../libexec/csd-xrandr csd-xrandr )
( cd usr/bin ; rm -rf csd-xsettings )
( cd usr/bin ; ln -sf ../libexec/csd-xsettings csd-xsettings )
( cd usr/lib64/cinnamon-settings-daemon ; rm -rf csd-a11y-keyboard )
( cd usr/lib64/cinnamon-settings-daemon ; ln -sf ../../libexec/csd-a11y-keyboard csd-a11y-keyboard )
( cd usr/lib64/cinnamon-settings-daemon ; rm -rf csd-a11y-settings )
( cd usr/lib64/cinnamon-settings-daemon ; ln -sf ../../libexec/csd-a11y-settings csd-a11y-settings )
( cd usr/lib64/cinnamon-settings-daemon ; rm -rf csd-automount )
( cd usr/lib64/cinnamon-settings-daemon ; ln -sf ../../libexec/csd-automount csd-automount )
( cd usr/lib64/cinnamon-settings-daemon ; rm -rf csd-background )
( cd usr/lib64/cinnamon-settings-daemon ; ln -sf ../../libexec/csd-background csd-background )
( cd usr/lib64/cinnamon-settings-daemon ; rm -rf csd-backlight-helper )
( cd usr/lib64/cinnamon-settings-daemon ; ln -sf ../../libexec/csd-backlight-helper csd-backlight-helper )
( cd usr/lib64/cinnamon-settings-daemon ; rm -rf csd-clipboard )
( cd usr/lib64/cinnamon-settings-daemon ; ln -sf ../../libexec/csd-clipboard csd-clipboard )
( cd usr/lib64/cinnamon-settings-daemon ; rm -rf csd-color )
( cd usr/lib64/cinnamon-settings-daemon ; ln -sf ../../libexec/csd-color csd-color )
( cd usr/lib64/cinnamon-settings-daemon ; rm -rf csd-cursor )
( cd usr/lib64/cinnamon-settings-daemon ; ln -sf ../../libexec/csd-cursor csd-cursor )
( cd usr/lib64/cinnamon-settings-daemon ; rm -rf csd-housekeeping )
( cd usr/lib64/cinnamon-settings-daemon ; ln -sf ../../libexec/csd-housekeeping csd-housekeeping )
( cd usr/lib64/cinnamon-settings-daemon ; rm -rf csd-input-helper )
( cd usr/lib64/cinnamon-settings-daemon ; ln -sf ../../libexec/csd-input-helper csd-input-helper )
( cd usr/lib64/cinnamon-settings-daemon ; rm -rf csd-keyboard )
( cd usr/lib64/cinnamon-settings-daemon ; ln -sf ../../libexec/csd-keyboard csd-keyboard )
( cd usr/lib64/cinnamon-settings-daemon ; rm -rf csd-list-wacom )
( cd usr/lib64/cinnamon-settings-daemon ; ln -sf ../../libexec/csd-list-wacom csd-list-wacom )
( cd usr/lib64/cinnamon-settings-daemon ; rm -rf csd-locate-pointer )
( cd usr/lib64/cinnamon-settings-daemon ; ln -sf ../../libexec/csd-locate-pointer csd-locate-pointer )
( cd usr/lib64/cinnamon-settings-daemon ; rm -rf csd-media-keys )
( cd usr/lib64/cinnamon-settings-daemon ; ln -sf ../../libexec/csd-media-keys csd-media-keys )
( cd usr/lib64/cinnamon-settings-daemon ; rm -rf csd-mouse )
( cd usr/lib64/cinnamon-settings-daemon ; ln -sf ../../libexec/csd-mouse csd-mouse )
( cd usr/lib64/cinnamon-settings-daemon ; rm -rf csd-orientation )
( cd usr/lib64/cinnamon-settings-daemon ; ln -sf ../../libexec/csd-orientation csd-orientation )
( cd usr/lib64/cinnamon-settings-daemon ; rm -rf csd-power )
( cd usr/lib64/cinnamon-settings-daemon ; ln -sf ../../libexec/csd-power csd-power )
( cd usr/lib64/cinnamon-settings-daemon ; rm -rf csd-print-notifications )
( cd usr/lib64/cinnamon-settings-daemon ; ln -sf ../../libexec/csd-print-notifications csd-print-notifications )
( cd usr/lib64/cinnamon-settings-daemon ; rm -rf csd-printer )
( cd usr/lib64/cinnamon-settings-daemon ; ln -sf ../../libexec/csd-printer csd-printer )
( cd usr/lib64/cinnamon-settings-daemon ; rm -rf csd-screensaver-proxy )
( cd usr/lib64/cinnamon-settings-daemon ; ln -sf ../../libexec/csd-screensaver-proxy csd-screensaver-proxy )
( cd usr/lib64/cinnamon-settings-daemon ; rm -rf csd-smartcard )
( cd usr/lib64/cinnamon-settings-daemon ; ln -sf ../../libexec/csd-smartcard csd-smartcard )
( cd usr/lib64/cinnamon-settings-daemon ; rm -rf csd-sound )
( cd usr/lib64/cinnamon-settings-daemon ; ln -sf ../../libexec/csd-sound csd-sound )
( cd usr/lib64/cinnamon-settings-daemon ; rm -rf csd-wacom )
( cd usr/lib64/cinnamon-settings-daemon ; ln -sf ../../libexec/csd-wacom csd-wacom )
( cd usr/lib64/cinnamon-settings-daemon ; rm -rf csd-wacom-osd )
( cd usr/lib64/cinnamon-settings-daemon ; ln -sf ../../libexec/csd-wacom-osd csd-wacom-osd )
( cd usr/lib64/cinnamon-settings-daemon ; rm -rf csd-xrandr )
( cd usr/lib64/cinnamon-settings-daemon ; ln -sf ../../libexec/csd-xrandr csd-xrandr )
( cd usr/lib64/cinnamon-settings-daemon ; rm -rf csd-xsettings )
( cd usr/lib64/cinnamon-settings-daemon ; ln -sf ../../libexec/csd-xsettings csd-xsettings )

==> cinnamon-settings-daemon-6.0.0-x86_64-1_csb.txz: install/doinst.sh <==
if [ -e usr/share/icons/hicolor/icon-theme.cache ]; then
  if [ -x /usr/bin/gtk-update-icon-cache ]; then
    /usr/bin/gtk-update-icon-cache usr/share/icons/hicolor >/dev/null 2>&1
  fi
fi

if [ -e usr/share/glib-2.0/schemas ]; then
  if [ -x /usr/bin/glib-compile-schemas ]; then
    /usr/bin/glib-compile-schemas usr/share/glib-2.0/schemas >/dev/null 2>&1
  fi
fi
( cd usr/bin ; rm -rf csd-a11y-settings )
( cd usr/bin ; ln -sf ../libexec/csd-a11y-settings csd-a11y-settings )
( cd usr/bin ; rm -rf csd-automount )
( cd usr/bin ; ln -sf ../libexec/csd-automount csd-automount )
( cd usr/bin ; rm -rf csd-background )
( cd usr/bin ; ln -sf ../libexec/csd-background csd-background )
( cd usr/bin ; rm -rf csd-backlight-helper )
( cd usr/bin ; ln -sf ../libexec/csd-backlight-helper csd-backlight-helper )
( cd usr/bin ; rm -rf csd-clipboard )
( cd usr/bin ; ln -sf ../libexec/csd-clipboard csd-clipboard )
( cd usr/bin ; rm -rf csd-color )
( cd usr/bin ; ln -sf ../libexec/csd-color csd-color )
( cd usr/bin ; rm -rf csd-housekeeping )
( cd usr/bin ; ln -sf ../libexec/csd-housekeeping csd-housekeeping )
( cd usr/bin ; rm -rf csd-input-helper )
( cd usr/bin ; ln -sf ../libexec/csd-input-helper csd-input-helper )
( cd usr/bin ; rm -rf csd-keyboard )
( cd usr/bin ; ln -sf ../libexec/csd-keyboard csd-keyboard )
( cd usr/bin ; rm -rf csd-media-keys )
( cd usr/bin ; ln -sf ../libexec/csd-media-keys csd-media-keys )
( cd usr/bin ; rm -rf csd-power )
( cd usr/bin ; ln -sf ../libexec/csd-power csd-power )
( cd usr/bin ; rm -rf csd-print-notifications )
( cd usr/bin ; ln -sf ../libexec/csd-print-notifications csd-print-notifications )
( cd usr/bin ; rm -rf csd-printer )
( cd usr/bin ; ln -sf ../libexec/csd-printer csd-printer )
( cd usr/bin ; rm -rf csd-screensaver-proxy )
( cd usr/bin ; ln -sf ../libexec/csd-screensaver-proxy csd-screensaver-proxy )
( cd usr/bin ; rm -rf csd-settings-remap )
( cd usr/bin ; ln -sf ../libexec/csd-settings-remap csd-settings-remap )
( cd usr/bin ; rm -rf csd-smartcard )
( cd usr/bin ; ln -sf ../libexec/csd-smartcard csd-smartcard )
( cd usr/bin ; rm -rf csd-wacom )
( cd usr/bin ; ln -sf ../libexec/csd-wacom csd-wacom )
( cd usr/bin ; rm -rf csd-xsettings )
( cd usr/bin ; ln -sf ../libexec/csd-xsettings csd-xsettings )
( cd usr/lib64/cinnamon-settings-daemon ; rm -rf csd-a11y-settings )
( cd usr/lib64/cinnamon-settings-daemon ; ln -sf ../../libexec/csd-a11y-settings csd-a11y-settings )
( cd usr/lib64/cinnamon-settings-daemon ; rm -rf csd-automount )
( cd usr/lib64/cinnamon-settings-daemon ; ln -sf ../../libexec/csd-automount csd-automount )
( cd usr/lib64/cinnamon-settings-daemon ; rm -rf csd-background )
( cd usr/lib64/cinnamon-settings-daemon ; ln -sf ../../libexec/csd-background csd-background )
( cd usr/lib64/cinnamon-settings-daemon ; rm -rf csd-backlight-helper )
( cd usr/lib64/cinnamon-settings-daemon ; ln -sf ../../libexec/csd-backlight-helper csd-backlight-helper )
( cd usr/lib64/cinnamon-settings-daemon ; rm -rf csd-clipboard )
( cd usr/lib64/cinnamon-settings-daemon ; ln -sf ../../libexec/csd-clipboard csd-clipboard )
( cd usr/lib64/cinnamon-settings-daemon ; rm -rf csd-color )
( cd usr/lib64/cinnamon-settings-daemon ; ln -sf ../../libexec/csd-color csd-color )
( cd usr/lib64/cinnamon-settings-daemon ; rm -rf csd-housekeeping )
( cd usr/lib64/cinnamon-settings-daemon ; ln -sf ../../libexec/csd-housekeeping csd-housekeeping )
( cd usr/lib64/cinnamon-settings-daemon ; rm -rf csd-input-helper )
( cd usr/lib64/cinnamon-settings-daemon ; ln -sf ../../libexec/csd-input-helper csd-input-helper )
( cd usr/lib64/cinnamon-settings-daemon ; rm -rf csd-keyboard )
( cd usr/lib64/cinnamon-settings-daemon ; ln -sf ../../libexec/csd-keyboard csd-keyboard )
( cd usr/lib64/cinnamon-settings-daemon ; rm -rf csd-media-keys )
( cd usr/lib64/cinnamon-settings-daemon ; ln -sf ../../libexec/csd-media-keys csd-media-keys )
( cd usr/lib64/cinnamon-settings-daemon ; rm -rf csd-power )
( cd usr/lib64/cinnamon-settings-daemon ; ln -sf ../../libexec/csd-power csd-power )
( cd usr/lib64/cinnamon-settings-daemon ; rm -rf csd-print-notifications )
( cd usr/lib64/cinnamon-settings-daemon ; ln -sf ../../libexec/csd-print-notifications csd-print-notifications )
( cd usr/lib64/cinnamon-settings-daemon ; rm -rf csd-printer )
( cd usr/lib64/cinnamon-settings-daemon ; ln -sf ../../libexec/csd-printer csd-printer )
( cd usr/lib64/cinnamon-settings-daemon ; rm -rf csd-screensaver-proxy )
( cd usr/lib64/cinnamon-settings-daemon ; ln -sf ../../libexec/csd-screensaver-proxy csd-screensaver-proxy )
( cd usr/lib64/cinnamon-settings-daemon ; rm -rf csd-settings-remap )
( cd usr/lib64/cinnamon-settings-daemon ; ln -sf ../../libexec/csd-settings-remap csd-settings-remap )
( cd usr/lib64/cinnamon-settings-daemon ; rm -rf csd-smartcard )
( cd usr/lib64/cinnamon-settings-daemon ; ln -sf ../../libexec/csd-smartcard csd-smartcard )
( cd usr/lib64/cinnamon-settings-daemon ; rm -rf csd-wacom )
( cd usr/lib64/cinnamon-settings-daemon ; ln -sf ../../libexec/csd-wacom csd-wacom )
( cd usr/lib64/cinnamon-settings-daemon ; rm -rf csd-xsettings )
( cd usr/lib64/cinnamon-settings-daemon ; ln -sf ../../libexec/csd-xsettings csd-xsettings )
